==> fs_moodle5-00-01_1-9-19_20120721.zip: moodle/message/send.php <==
<?php // $Id: send.php,v 1.22.2.4 2008/05/08 03:41:11 jerome Exp $

require('../config.php');
require('lib.php');

require_login();

if (isguest()) {
    redirect($CFG->wwwroot);
}

if (empty($CFG->messaging)) {
    error("Messaging is disabled on this site");
}

if (has_capability('moodle/site:sendmessage', get_context_instance(CONTEXT_SYSTEM))) {


/// Don't use print_header, for more speed
    $stylesheetshtml = '';
    foreach ($CFG->stylesheets as $stylesheet) {
        $stylesheetshtml .= '<link rel="stylesheet" type="text/css" href="'.$stylesheet.'" />';
    }

/// Select direction
    if ( get_string('thisdirection') == 'rtl' ) {
        $direction = ' dir="rtl"';
    } else {
        $direction = ' dir="ltr"';
    }

    @header('Content-Type: text/html; charset=utf-8');
    echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">'."\n";
    echo "<html $direction xmlns=\"http://www.w3.org/1999/xhtml\">\n<head>\n";
    echo '<meta http-equiv="content-type" content="text/html; charset=utf-8" />';
    echo $stylesheetshtml;
    include($CFG->javascript);

/// Script parameters
    $userid   = required_param('id', PARAM_INT);
    $message  = optional_param('message', '', PARAM_CLEANHTML);
    $format   = optional_param('format', FORMAT_MOODLE, PARAM_INT);

/// Check the user we are talking to is valid
    if (! $user = get_record('user', 'id', $userid)) {
        error("User ID was incorrect");
    }

/// Check that the user is not blocking us!!
    if ($contact = get_record('message_contacts', 'userid', $user->id, 'contactid', $USER->id)) {
        if ($contact->blocked and !has_capability('moodle/site:readallmessages', get_context_instance(CONTEXT_SYSTEM))) {
            print_heading(get_string('userisblockingyou', 'message'));
            exit;
        }
    }
    $userpreferences = get_user_preferences(NULL, NULL, $user->id);

    if (!empty($userpreferences['message_blocknoncontacts'])) {  // User is blocking non-contacts
        if (empty($contact)) {   // We are not a contact!
            print_heading(get_string('userisblockingyounoncontact', 'message'));
            exit;
        }
    }


    if ($message!='' and confirm_sesskey()) {   /// Current user has just sent a message

    /// Save it to the database...
        $messageid = message_post_message($USER, $user, addslashes($message), $format, 'direct');

    /// Format the message as HTML
        $options = NULL;
        $options->para = false;
        $options->newlines = true;
        $message = format_text($message, $format, $options);

        $time = userdate(time(), get_string('strftimedatetimeshort'));
        $message = '<div class="message me"><span class="author">'.fullname($USER).'</span> '.
                   '<span class="time">['.$time.']</span>: '.
                   '<span class="content">'.$message.'</span></div>';
        $message = addslashes_js($message);  // So Javascript can write it

    /// Then write it to our own message screen immediately
        echo "\n<script type=\"text/javascript\">\n<!--\n";
        echo 'parent.messages.document.write(\''.$message."\\n');\n";
        echo 'parent.messages.scroll(1,5000000);';
        echo "\n-->\n</script>\n\n";

        add_to_log(SITEID, 'message', 'write', 'history.php?user1='.$user->id.'&amp;user2='.$USER->id.'#m'.$messageid, $user->id);
    }

    echo '<title> </title></head>';


    echo '<body class="message course-1" id="message-send">';
    echo '<center>';
    echo '<form id="editing" method="post" action="send.php">';
    echo '<div>';
    echo '<input type="hidden" name="id" value="'.$user->id.'" />';
    echo '<input type="hidden" name="sesskey" value="'.$USER->sesskey.'" />';

    $usehtmleditor = (can_use_html_editor() && get_user_preferences('message_usehtmleditor', 0));
    if ($usehtmleditor) {
        echo '<table><tr><td class="fixeditor" align="center">';
        print_textarea($usehtmleditor, 9, 200, 0, 0, 'message', '');
        echo '</td></tr></table>';
// (Shirai109): メッセージによる電子メール送信時のSubjectを入力欄第１行目の文章のみとする改良 (2008/12/19)
// (Shirai109): ここからコメントアウト
//      echo '<input type="submit" value="'.get_string('sendmessage', 'message').'" />';
// (Shirai109): ここから挿入
        if (!fs_function_enable('FS_DISABLE_MESSAGESUBJECT')) {
            echo '<input type="submit" value="'.get_string('sendmessage', 'message').'" />';
        } else {
            echo '<input Title="'.get_string('1stLineIsSubject', 'fs_moodle').'" type="submit" value="'.get_string('sendmessage', 'message').'" />';
        }
// (Shirai109): ここまで追加
        use_html_editor('message', 'formatblock subscript superscript copy cut paste clean undo redo justifyleft justifycenter justifyright justifyfull lefttoright righttoleft insertorderedlist insertunorderedlist outdent indent inserthorizontalrule createanchor nolink inserttable');
        echo '<input type="hidden" name="format" value="'.FORMAT_HTML.'" />';
    } else {
        print_textarea(false, 5, 34, 0, 0, 'message', '');
        echo '<input type="hidden" name="format" value="'.FORMAT_MOODLE.'" />';
// (Shirai109): メッセージによる電子メール送信時のSubjectを入力欄第１行目の文章のみとする改良 (2008/12/19)
// (Shirai109): ここからコメントアウト
//      echo '<br /><input type="submit" value="'.get_string('sendmessage', 'message').'" />';
// (Shirai109): ここから挿入
        if (!fs_function_enable('FS_DISABLE_MESSAGESUBJECT')) {
            echo '<br /><input type="submit" value="'.get_string('sendmessage', 'message').'" />';
        } else {
            echo '<br /><input Title="'.get_string('1stLineIsSubject', 'fs_moodle').'" type="submit" value="'.get_string('sendmessage', 'message').'" />';
        }
// (Shirai109): ここまで追加
    }
    echo '</div>';
    echo '</form>';
    if (!empty($CFG->messagewasjustemailed)) {
        notify(get_string('mailsent', 'message'), 'notifysuccess');
    }
// (Shirai113): メッセージ(message)機能のメール送信失敗時にエラーメッセージをきちんと表示するための改良 (2009/01/10)
// (Shirai113): ここから追加
    else if (isset($CFG->messagewasjustemailed) && ($CFG->messagewasjustemailed === false))
    {
        notify('（警告）メール経由での送信が失敗しました。');
    }
// (Shirai113): ここまで追加
    echo '<div class="noframesjslink"><a target="_parent" href="discussion.php?id='.$userid.'&amp;noframesjs=1">'.get_string('noframesjs', 'message').'</a></div>';
    echo '</center>';

    echo "\n<script type=\"text/javascript\">\n<!--\n";                  /// Focus on the textarea
    echo 'document.getElementById("edit-message").focus();'."\n";
    echo "\n-->\n</script>\n\n";

// (Shirai081): メッセージ関係でポップアップするウィンドウに”ウィンドウを閉じる”ボタンを追加する改良 (2008/08/19)
// (Shirai081): ここから追加
    output_CloseWindowButton(true, true);
// (Shirai081): ここまで追加
    echo '</body></html>';
}
?>

==> fs_moodle5-00-02_1-8-14_20130318.zip: moodle/message/send.php <==
<?php // $Id: send.php,v 1.18.2.4 2008/05/01 05:21:11 scyrma Exp $

require('../config.php');
require('lib.php');

require_login();

if (isguest()) {
    redirect($CFG->wwwroot);
}

if (empty($CFG->messaging)) {
    error("Messaging is disabled on this site");
}

if (has_capability('moodle/site:sendmessage', get_context_instance(CONTEXT_SYSTEM))) {


/// Don't use print_header, for more speed
    $stylesheetshtml = '';
    foreach ($CFG->stylesheets as $stylesheet) {
        $stylesheetshtml .= '<link rel="stylesheet" type="text/css" href="'.$stylesheet.'" />';
    }

/// Select direction
    if ( get_string('thisdirection') == 'rtl' ) {
        $direction = ' dir="rtl"';
    } else {
        $direction = ' dir="ltr"';
    }

    @header('Content-Type: text/html; charset=utf-8');
    echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">'."\n";
    echo "<html $direction xmlns=\"http://www.w3.org/1999/xhtml\">\n<head>\n";
    echo '<meta http-equiv="content-type" content="text/html; charset=utf-8" />';
    echo $stylesheetshtml;
    include($CFG->javascript);

/// Script parameters
    $userid   = required_param('id', PARAM_INT);
    $message  = optional_param('message', '', PARAM_CLEANHTML);
    $format   = optional_param('format', FORMAT_MOODLE, PARAM_INT);

/// Check the user we are talking to is valid
    if (! $user = get_record('user', 'id', $userid)) {
        error("User ID was incorrect");
    }

/// Check that the user is not blocking us!!
    if ($contact = get_record('message_contacts', 'userid', $user->id, 'contactid', $USER->id)) {
        if ($contact->blocked and !has_capability('moodle/site:readallmessages', get_context_instance(CONTEXT_SYSTEM, SITEID))) {
            print_heading(get_string('userisblockingyou', 'message'));
            exit;
        }
    }
    $userpreferences = get_user_preferences(NULL, NULL, $user->id);

    if (!empty($userpreferences['message_blocknoncontacts'])) {  // User is blocking non-contacts
        if (empty($contact)) {   // We are not a contact!
            print_heading(get_string('userisblockingyounoncontact', 'message'));
            exit;
        }
    }


    if ($message!='' and confirm_sesskey()) {   /// Current user has just sent a message

    /// Save it to the database...
        $messageid = message_post_message($USER, $user, addslashes($message), $format, 'direct');

    /// Format the message as HTML
        $options = NULL;
        $options->para = false;
        $options->newlines = true;
        $message = format_text($message, $format, $options);

        $time = userdate(time(), get_string('strftimedaytime'));
        $message = '<div class="message me"><span class="author">'.fullname($USER).'</span> '.
                   '<span class="time">['.$time.']</span>: '.
                   '<span class="content">'.$message.'</span></div>';
        $message = addslashes_js($message);  // So Javascript can write it

    /// Then write it to our own message screen immediately
        echo "\n<script type=\"text/javascript\">\n<!--\n";
        echo 'parent.messages.document.write(\''.$message."\\n');\n";
        echo 'parent.messages.scroll(1,5000000);';
        echo "\n-->\n</script>\n\n";

        add_to_log(SITEID, 'message', 'write', 'history.php?user1='.$user->id.'&amp;user2='.$USER->id.'#m'.$messageid, $user->id);
    }

    echo '<title></title></head>';


    echo '<body class="message course-1" id="message-send">';
    echo '<center>';
    echo '<form id="editing" method="post" action="send.php">';
    echo '<input type="hidden" name="id" value="'.$user->id.'" />';
    echo '<input type="hidden" name="sesskey" value="'.$USER->sesskey.'" />';

    $usehtmleditor = (can_use_html_editor() && get_user_preferences('message_usehtmleditor', 0));
    if ($usehtmleditor) {
        echo '<table align="center"><tr><td align="center">';
        print_textarea($usehtmleditor, 8, 34, 0, 0, 'message', '');
        echo '</td></tr></table>';
        use_html_editor('message', 'formatblock subscript superscript copy cut paste clean undo redo justifyleft justifycenter justifyright justifyfull lefttoright righttoleft insertorderedlist insertunorderedlist outdent indent inserthorizontalrule createanchor nolink inserttable');
        echo '<input type="hidden" name="format" value="'.FORMAT_HTML.'" />';
    } else {
        print_textarea(false, 5, 34, 0, 0, 'message', '');
        echo '<input type="hidden" name="format" value="'.FORMAT_MOODLE.'" />';
    }
// (Shirai109): メッセージによる電子メール送信時のSubjectを入力欄第１行目の文章のみとする改良 (2008/12/19)
// (Shirai109): ここからコメントアウト
//  echo '<br /><input type="submit" value="'.get_string('sendmessage', 'message').'" />';
// (Shirai109): ここから挿入
    if (!fs_function_enable('FS_DISABLE_MESSAGESUBJECT')) {
        echo '<br /><input type="submit" value="'.get_string('sendmessage', 'message').'" />';
    } else {
        echo '<br /><input Title="'.get_string('1stLineIsSubject', 'fs_moodle').'" type="submit" value="'.get_string('sendmessage', 'message').'" />';
    }
// (Shirai109): ここまで追加
    echo '</form>';
    echo '<div class="noframesjslink"><a target="_parent" href="discussion.php?id='.$userid.'&amp;noframesjs=1">'.get_string('noframesjs', 'message').'</a></div>';
    echo '</center>';

    echo "\n<script type=\"text/javascript\">\n<!--\n";                  /// Focus on the textarea
    echo 'document.getElementById("edit-message").focus();'."\n";
    echo "\n-->\n</script>\n\n";

// (Shirai081): メッセージ関係でポップアップするウィンドウに”ウィンドウを閉じる”ボタンを追加する改良 (2008/08/19)
// (Shirai081): ここから追加
    output_CloseWindowButton(true, true);
// (Shirai081): ここまで追加
    echo '</body></html>';
}
?>
